@@ -16,14 +16,13 @@ class apiCard(BaseDiff):
                          url_update="/OCartao/Cartoes",
                          url_get_all="/Cartoes",
                          url_get_detail="/OCartao/CartaoDetalhes",
+                         key_detail="cartoesLight",
                          url_delete="/Cartoes",
                          submodules={
-                             "contas": Conta(),
-                             "operadoraCartao": Operadora()
+                             "contasId": Conta(),
+                             "operadoraCartaoId": Operadora()
                          })
 
-        # self.operadora = Operadora()
-        # self.conta = Conta()
         if not apiCard.first_get:
             self.get_all()
             apiCard.first_get = True
@@ -31,9 +30,6 @@ class apiCard(BaseDiff):
     def get_all(self):
         apiCard.items = super().get_all()
 
-    def details(self, item_id):
-        return super().details(item_id)["cartoesLight"]
-
     def item_id(self, data):
         for i in apiCard.items:
             if (i["descricao"] == data["descricao"]
