@@ -20,10 +20,11 @@ class Servicos(BaseDiff):
             url_update="/OServicosComis/UpdateServicosLight",
             url_get_all="/OGservsServicos/ListaDetalhesServicosLight",
             url_get_detail="/OServicos/DetalhesServicosLight",
+            key_detail="servicoLightModel",
             url_delete="/Servicos/DeleteServicos",
             url_inactive="/OServicosComis/UpdateServicosLight",
             key_active="flagAtivo",
-            submodules={"gserv": Gservis()})
+            submodules={"gservId": Gservis()})
 
         if not Servicos.first_get:
             self.get_all()
@@ -31,11 +32,3 @@ class Servicos(BaseDiff):
 
     def get_all(self):
         Servicos.items = super().get_all()
-
-    def details(self, item_id):
-        return super().details(item_id)["servicoLightModel"]
-
-    def name_to_id(self, data):
-        data["valPercComissao"] = "P"
-        data["valPercCustos"] = "P"
-        return super().name_to_id(data)
