@@ -5,10 +5,13 @@ from oneparams.utils import deemphasize
 
 
 def servico(book, reset=False):
+    print("analyzing spreadsheet")
+
     ex = Excel(book, "servico")
 
+    ex.add_column(key="flagAtivo", name="ativo", required=False, default=True)
     ex.add_column(key="descricao", name="nome")
-    ex.add_column(key="gserv", name="grupo")
+    ex.add_column(key="gservId", name="grupo")
     ex.add_column(key="preco", name="valor", default=0, types="float")
     ex.add_column(key="comissao", name="comissao", default=0, types="float")
     ex.add_column(key="tempoExecucao",
@@ -35,10 +38,18 @@ def servico(book, reset=False):
                   required=False,
                   default=True,
                   types="bool")
-    one = Servicos()
+    ex.add_column(key="valPercComissao",
+                  name="tipo comissao",
+                  required=False,
+                  default="P")
+    ex.add_column(key="valPercCustos",
+                  name="tipo custo",
+                  required=False,
+                  default="P")
+    ex.clean_columns()
 
-    print("analyzing spreadsheet")
-    data = ex.data_all(check_row=checks)
+    one = Servicos()
+    data = ex.data_all(check_row=checks, check_final=check_all)
 
     if reset:
         one.delete_all()
@@ -51,19 +62,19 @@ def servico(book, reset=False):
     grupo.clear()
 
 
-def checks(row, data, previous):
+def checks(row, data):
     erros = False
     if data["descricao"] is None:
-        print(f'ERROR! in line {row + 1}: empty name')
+        print(f'ERROR! in line {row}: empty name')
         erros = True
     if len(data["descricao"]) > 50:
         print(
-            f'ERROR! in line {row + 1}: Service {data["descricao"]} name size {len(data["descricao"])}/50'
+            f'ERROR! in line {row}: Service {data["descricao"]} name size {len(data["descricao"])}/50'
         )
         erros = True
-    if data["gserv"] is None:
+    if data["gservId"] is None:
         print(
-            f'ERROR! in line {row + 1}: Service {data["descricao"]} have empty group'
+            f'ERROR! in line {row}: Service {data["descricao"]} have empty group'
         )
         erros = True
 
@@ -71,17 +82,28 @@ def checks(row, data, previous):
     if comissao <= 1:
         data["comissao"] = comissao * 100
 
-    for prev in previous:
-        descricao = deemphasize(data["descricao"])
-        prev_descricao = deemphasize(prev["data"]["descricao"])
-        if descricao == prev_descricao:
-            print(
-                f'ERROR! in lines {row + 1} and {prev["row"] +1}: Service {data["descricao"]} is duplicated'
-            )
-            erros = True
-
     if erros:
         raise Exception
 
     one = Servicos()
     return one.name_to_id(data)
+
+
+def check_all(self, data):
+    erros = False
+    duplic = data[data.duplicated(keep=False, subset=["descricao"])]
+    for i in duplic.index:
+        for j in duplic.index:
+            if (duplic.loc[i, "descricao"] == duplic.loc[j, "descricao"]
+                    and j != i):
+                print("ERROR! in lines {} and {}: Service {} is duplicated".
+                      format(self.row(duplic.loc[i].name),
+                             self.row(duplic.loc[j].name),
+                             duplic.loc[i, 'descricao']))
+                duplic = duplic.drop(index=i)
+                erros = True
+                break
+    if erros:
+        raise Exception
+
+    return data
