@@ -2,13 +2,13 @@
 import argparse
 import sys
 
-import xlrd
+import pandas as pd
 
 from oneparams.api.login import login
 from oneparams.args import parse_base
 from oneparams.excel.card import cards
 from oneparams.excel.colaborador import colaborador
-from oneparams.excel.comissao import comissao
+from oneparams.excel.comissao import Comissao
 from oneparams.excel.servicos import servico
 
 
@@ -49,12 +49,12 @@ def one():
     args = parser.parse_args()
 
     try:
-        book = xlrd.open_workbook(args.worksheet)
-    except FileNotFoundError:
-        print("File not found!!")
+        book = pd.ExcelFile(args.worksheet)
+    except FileNotFoundError as exp:
+        print(exp)
         sys.exit()
-    except xlrd.biffh.XLRDError:
-        print("Unsupported file!!")
+    except ValueError as exp:
+        print(exp)
         sys.exit()
 
     one = login()
@@ -73,7 +73,7 @@ def one():
         cards(book, reset=args.reset)
 
     if args.cmd == "comm":
-        comissao(book, reset=args.reset)
+        Comissao(book, reset=args.reset)
 
 
 def main():
